<?php
/**
 * @package   admintoolswp
 * @copyright Copyright (c)2017-2019 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL version 3 or later
 */

namespace Akeeba\AdminTools\Admin\Helper;

defined('ADMINTOOLSINC') or die;

// Prevent fatal errors in auto-prepend mode
if (!function_exists('__')){
	function __($text, $domain = 'default'){
		return $text;
	}
}

/**
 * In Worpdress you can't dynamically create language strings, since they won't be recognized.
 * This class will serve as central place where we can list all the strings and reference to them with a token
 *
 * @package Akeeba\AdminTools\Admin\Helper
 */
class Language
{
	/**
	 * The cache of translation string map
	 *
	 * @var   array
	 */
	protected static $strings = array();

	/**
	 * Return a translated string located by its key.
	 *
	 * @param   string  $key  The translation key, e.g. COM_ADMINTOOLS
	 *
	 * @return  string
	 */
	public static function _($key)
	{
		if (!self::$strings)
		{
			self::buildStrings();
		}

		$key = strtoupper($key);

		if (isset(self::$strings[$key]))
		{
			return self::$strings[$key];
		}

		return $key;
	}

	/**
	 * Applies sprintf() on the translated string which is located by its key
	 *
	 * @param   string  $key  The translation key, e.g. COM_ADMINTOOLS
	 *
	 * @return  string
	 */
	public static function sprintf($key)
	{
		$args  = func_get_args();
		$count = count($args);

		if ($count < 1)
		{
			return '';
		}

		$args[0] = self::_($key);

		// Replace custom named placeholders with sprintf style placeholders
		$args[0] = preg_replace('/\[\[%([0-9]+):[^\]]*\]\]/', '%\1$s', $args[0]);

		return call_user_func_array('sprintf', $args);
	}

	/**
	 * Map our common string format (keys) to WordPress translated strings
	 *
	 * @return  void
	 */
	protected static function buildStrings()
	{
		self::$strings['AKEEBA_COMMON_PHPVERSIONTOOOLD_WARNING_BODY'] =
			__('Your site is running on PHP %s which stopped receiving security updates since %s. Using this on a live site is <b>dangerous</b>: unpatched security issues can get your site hacked. Moreover, we will only support obsolete versions of PHP for nine months after their end-of-life date. Therefore we will discontinue support for your PHP version on %s. We strongly advise you to ask your host to upgrade your site to PHP %s or later.', 'admintoolswp');
		self::$strings['AKEEBA_COMMON_PHPVERSIONTOOOLD_WARNING_TITLE'] =
			__('You are using an obsolete PHP version', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS'] =
			__('Admin Tools', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_BLACKLISTEDADDRESSES_ERR_NOTENABLED_BODY'] =
			__('The IP addresses you enter below will <strong>not</strong> be taken into account until you enable the “Disallow site access to IPs in Blacklist” option in the Configure WAF page.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_BLACKLISTEDADDRESSES_ERR_NOTENABLED_TITLE'] =
			__('The IP blacklist feature is not enabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_BLACKLISTEDADDRESSES_EXPORT'] =
			__('Export IP', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_BLACKLISTEDADDRESSES_IMPORT'] =
			__('Import IP', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CHANGEDBCOLLATION'] =
			__('Change Database Collation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGURATION'] =
			__('Admin Tools Configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_CUSTOMADMIN_NOTICE_HEAD'] =
			__('WARNING!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_CUSTOMADMIN_NOTICE_TEXT'] =
			__('On some sites this feature may perform erratically, not work at all, or make it impossible to log in. We are aware and there is no workaround for this. For this reason this feature is provided <strong>WITHOUT SUPPORT</strong>. Please read the documentation for more information.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_IPBL_TIP'] =
			__('When enabled, if the visitor\'s IP is in the Blacklist (see the <a href="%s">IP Blacklist</a> feature) they will immediately get a 403 Forbidden error message upon trying to access your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_IPWL_TIP'] =
			__('When enabled, only Administrators with IPs in the Whitelist (see the <a href="%s">Administrator IP Whitelist</a> feature) will be allowed to access the site. All other attempts to access the administrator pages will be redirected to the site\'s home page. Be careful when using this feature! If you haven\'t added your own IP to the Whitelist you will get locked out of your site!<br/>This will affect only Administrator roles, lower roles (ie Subscribers) will be able to login normally.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_IPWORKAROUNDS_RECOMMENDED'] =
			__('The recommended setting for your site is: ', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_IPWORKAROUNDS_RECOMMENDED_WAIT'] =
			__('(please wait; thinking)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_IPWORKAROUNDS_TIP'] =
			__('If your server is behind a reverse proxy, a cache (e.g. Varnish) or a CDN you may need to enable this option. Do NOT enable on sites not using such a setup because it will degrade your security.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_OPT_IPWORKAROUNDS'] =
			__('Enable IP workarounds', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIRM_DELETE'] =
			__('Are you sure you want to delete this? You cannot undo this action later.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_BTN_FESECRETWORD_RESET'] =
			__('Apply the suggested Secret Word', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_EXCEPTIONS'] =
			__('Exceptions Graph', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_EXCEPTSTATS'] =
			__('Exceptions per type', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_FROMDATE'] =
			__('From', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_RELOADGRAPHS'] =
			__('Load graph', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS'] =
			__('Statistics', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_LAST7DAYS'] =
			__('Last 7 days', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_LASTMONTH'] =
			__('Last month', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_LASTYEAR'] =
			__('Last year', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_NODATA'] =
			__('There have been no exceptions over the last 30 days.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_THISMONTH'] =
			__('This month', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_THISYEAR'] =
			__('This year', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_TODAY'] =
			__('Today', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_DASHBOARD_STATS_YESTERDAY'] =
			__('Yesterday', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_HEADER_QUICKSETUP'] =
			__('Quick Setup', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_HEADER_QUICKSETUP_HELP'] =
			__('You should only run the Quick Setup Wizard once, when you first install Admin Tools. If you run it again it will override all your settings! If you want to adjust the configuration use the other buttons above.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_IP_UNBLOCKED'] =
			__('IP successfully unblocked', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONTROLPANEL_UNBLOCK_ME'] =
			__('Unblock my IP', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_ADMINPASSWORD_NOPASSWORD'] =
			__('You must supply a password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_ADMINPASSWORD_NOTAPPLIED'] =
			__('Could not apply the password protection. Please enable the FTP layer in your site\'s Global Configuration.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_ADMINPASSWORD_NOTUNAPPLIED'] =
			__('Could not remove the password protection. Please enable the FTP layer in your site\'s Global Configuration.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_ADMINPASSWORD_NOUSERNAME'] =
			__('You must supply a username', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_ADMINPASSWORD_PASSWORDNOMATCH'] =
			__('Passwords do not match', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_AUTOBANNEDADDRESS_NOITEMS'] =
			__('No IP is currently being automatically blocked', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_BADWORD_NEEDS_WORD'] =
			__('You have to specify a word to block', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_BADWORD_NOITEMS'] =
			__('No words to filter out have been specified', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_BLACKLISTEDADDRESS_NEEDS_IP'] =
			__('You have to specify an IP address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_BLACKLISTEDADDRESS_NOITEMS'] =
			__('No IPs have been added to the Blacklist yet', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_FESECRETWORD_HEADER'] =
			__('The frontend PHP File Change Scanner features are disabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_FESECRETWORD_INTRO'] =
			__('Your <em>Secret Word</em> is insecure and can be easily guessed. In order to protect your site Admin Tools has disabled access to frontend scheduling until you enter a secure Secret Word. The problem detected is:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_FESECRETWORD_WHATTODO_COMMON'] =
			__('Alternatively, click the button below to reset the secret word to the suggested value <code>%s</code> In either case you will need to update your CRON jobs with the new Secret Word.', 'admintoolswp');
		// TODO This is wrong
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_FESECRETWORD_WHATTODO_WORDPRESS'] =
			__('Please click on Options, Frontend and enter a more complex secret word.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_INVALIDDOWNLOADID'] =
			__('Invalid Download ID format. Please follow our instructions to get your Download ID. Do not enter your username, e-mail address or password in this box.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_NOTAUTHORIZED'] =
			__('You are not authorised to use this feature', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_CONTROLPANEL_OLDVERSION'] =
			__('This version of Admin Tools is over 90 days old. Most likely there is already a newer version available. Please check and apply any upgrades to make sure you get the best protection possible for your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_EMERGENCYOFFLINE_NOTAPPLIED'] =
			__('Could not apply the Emergency Off-Line mode. Click the Emergency Off-Line button for information on manually applying it.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_EMERGENCYOFFLINE_NOTUNAPPLIED'] =
			__('Could not deactivate the Emergency Off-Line mode. Click the Emergency Off-Line button for information on manually deactivating it.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_GEOGRAPHICBLOCKING_CANTDELETEOLD'] =
			__('Can not delete the old GeoIP.dat file. You have to download the file manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_GEOGRAPHICBLOCKING_CANTDOWNLOAD'] =
			__('Can not download the compressed GeoIP.dat.gz file from MaxMind.com.  You have to download the file manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_GEOGRAPHICBLOCKING_CANTUNCOMPRESS'] =
			__('Can not uncompress the downloaded file. You have to download the file manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_GEOGRAPHICBLOCKING_CANTWRITE'] =
			__('Can not write the new GeoIP.dat file. You have to download the file manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_GEOGRAPHICBLOCKING_NOGZSUPPORT'] =
			__('Your server does not support gzip compression. You have to download the file manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_FAILURE'] =
			__('Import failed. Reason %s', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_BADWORDS'] =
			__('An error occurred while importing bad words list', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_BLACKLIST'] =
			__('An error occurred while importing the IP blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_EMAILTEMPLATES'] =
			__('An error occurred while importing email templates', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_FILE'] =
			__('Missing file to import', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_FILE_TYPE'] =
			__('The file must be a CSV', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_LINE'] =
			__('Error on row %s, the row has been skipped and not imported', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_READING_FILE'] =
			__('An error occurred while reading the file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_UPLOAD'] =
			__('There was an error while uploading the file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_WAFBLACKLIST'] =
			__('An error occurred while importing the WAF blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_WAFEXCEPTIONS'] =
			__('An error occurred while importing WAF exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_IMPORTANDEXPORT_WHITELIST'] =
			__('An error occurred while importing the IP whitelist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_REDIRECTION_NEEDS_DEST'] =
			__('You must specify the new URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_REDIRECTION_NEEDS_SOURCE'] =
			__('You must specify the existing URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_REDIRECTION_NOITEMS'] =
			__('No redirections are specified yet. Use the New button to create one.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_SECURITYEXCEPTION_BAN_NOIP'] =
			__('No id specified or invalid id', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_SECURITYEXCEPTION_NOITEMS'] =
			__('No security exceptions found.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_WHITELISTEDADDRESS_NEEDS_IP'] =
			__('You have to specify an IP address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_WHITELISTEDADDRESS_NOITEMS'] =
			__('No IPs have been added to the Whitelist yet', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_WAFEXCEPTIONS_TYPE'] =
			__('Invalid exception type', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_WAFEXCEPTIONS_URL'] =
			__('You have to specify a URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERROR_REPORTING_DEFAULT'] =
			__('System default', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERROR_REPORTING_NONE'] =
			__('None', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERROR_REPORTING_ERRORS'] =
			__('Errors', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERROR_REPORTING_MINIMAL'] =
			__('Minimal', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERROR_REPORTING_FULL'] =
			__('Full', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERROR_REPORTING_DEVELOPER'] =
			__('Developer', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_BADWORDS'] =
			__('Bad words', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_DELIMITERS'] =
			__('CSV delimiters', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_DELIMITERS_CUSTOM'] =
			__('Custom delimiters', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_DELIMITERS_DESC'] =
			__('Choose the field delimiters found in your CSV file. You may need to open the file in a plain text editor (e.g. Notepad, gEdit, TextEdit) to see what is the actual delimiter used.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_DETAILS'] =
			__('Import details', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_EMAILTEMPLATES'] =
			__('Email templates', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_EMAILTEMPLATE_WARN'] =
			__('Exporting or importing the email templates could lead to memory outages issues. If you have an error while exporting or importing the settings, please exclude them and then try again.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FAIL'] =
			__('Import failed: %s', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FIELD_DELIMITERS'] =
			__('Field delimiter', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FIELD_DELIMITERS_DESC'] =
			__('Please enter the char used to separate fields.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FIELD_ENCLOSURE'] =
			__('Field enclosure', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FIELD_ENCLOSURE_DESC'] =
			__('Please enter the char (if present) used to wrap text data.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FILE'] =
			__('File', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FILE_DESC'] =
			__('Choose the CSV file to import', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_FINE_TUNING'] =
			__('Fine tuning', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_IMPORT_OK'] =
			__('Admin Tools settings imported successfully', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_IPBLACKLIST'] =
			__('IP Blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_IPWHITELIST'] =
			__('IP Whitelist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_NOFILE'] =
			__('Please upload the file with saved settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_OK'] =
			__('Import successfully completed. %s imported records', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_SELECT_DATA_WARN'] =
			__('Please select the settings you want to export', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_WAFBLACKLIST'] =
			__('WAF blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_WAFCONFIG'] =
			__('WAF configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_WAFEXCEPTIONS'] =
			__('WAF exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_IMPORTANDEXPORT_WITH_WARNINGS'] =
			__('Import successfully completed, but there were some warnings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_FEBENABLE_DESC'] =
			__('When enabled it allows you to the PHP File Change Scanner without logging in to the backend.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_FEBENABLE_LABEL'] =
			__('Enable frontend scheduling', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_FRONTEND_DESC'] =
			__('This allows you to schedule the PHP File Change Scanner by accessing a special frontend URL.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_FRONTEND_LABEL'] =
			__('Frontend', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_LONGCONFIGPAGE_DESC'] =
			__('When this option is disabled (default) the Configure WAF page will be shown using tabs. When this option is enabled the Configure WAF page will be shown in the old format: one long page.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_LONGCONFIGPAGE_LABEL'] =
			__('Long Configure WAF page', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_EMAIL_DESC'] =
			__('The email address that will receive update notifications', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_EMAIL_LABEL'] =
			__('Email for update notifications', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_FREQ_LABEL'] =
			__('Notification frequency', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_TIME_DAY'] =
			__('days', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_TIME_HOUR'] =
			__('hours', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_TIME_LABEL'] =
			__('Notification time', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_NOTIFICATION_TIME_MIN'] =
			__('minutes', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SCANDIFF_DESC'] =
			__('When this option is enabled, Admin Tools will calculate a diff (compact form of file differences) for each modified file detected by the PHP File Scanner feature. WARNING: This consumes A LOT of database space, about 20-40Mb for a typical site!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SCANDIFF_LABEL'] =
			__('Calculate diffs when scanning', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SCAN_DESC'] =
			__('Configure how the PHP File Scanner works', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SCAN_LABEL'] =
			__('File Scanner', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SECRETWORD_DESC'] =
			__('Protects the frontend scheduling feature from DoS attacks by requiring you to pass this secret word in the frontend scheduling URL. Please use long, complex passwords. Consult the documentation for more information.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SECRETWORD_LABEL'] =
			__('Secret word', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SHOWSTATS_DESC'] =
			__('Display graphs and statistics about security exceptions (Professional release only)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SHOWSTATS_LABEL'] =
			__('Show graphs and statistics', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_UPDATES'] =
			__('Updates', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MINSTABILITY_LABEL'] =
			__('Minimum stability', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MINSTABILITY_DESC'] =
			__('Only releases of at least this stability level will be shown as available updates.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MINSTABILITY_ALPHA'] =
			__('Alpha (unstable)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MINSTABILITY_BETA'] =
			__('Beta (testing)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MINSTABILITY_RC'] =
			__('Release Candidate', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MINSTABILITY_STABLE'] =
			__('Stable', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_USAGESTATS_DESC'] =
			__('Help us improve our software by anonymously and automatically reporting your PHP, MySQL and WordPress versions. This information will help us decide which versions of WordPress, PHP and MySQL to support in future versions. Note: we do NOT collect your site name, IP address or any other directly or indirectly unique identifying information.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_USAGESTATS_LABEL'] =
			__('Enable anonymous PHP, MySQL and WordPress version reporting', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_EMAILTIMEZONE_LABEL'] =
			__('Timezone for emails', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_EMAILTIMEZONE_DESC'] =
			__('All dates and times in the emails sent by Admin Tools to warn you about potential security issues will be expressed in the selected timezone. Default: UTC', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_APPLIED'] =
			__('Password protection successfully applied', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_INFO'] =
			__('When you apply the password protection, the following username and password will always be requested by your browser before you can log in to your administrator area.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_INTRO'] =
			__('This feature will password-protect your administrator area using .htaccess files. Your server must support this type of password protection.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_PASSWORD'] =
			__('Password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_PASSWORD2'] =
			__('Retype password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_PROTECT'] =
			__('Password-protect', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_UNAPPLIED'] =
			__('Password protection successfully removed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_UNPROTECT'] =
			__('Remove Password Protection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_USERNAME'] =
			__('Username', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADMINPASSWORD_WARN'] =
			__('If your administrator area becomes inaccessible, please remove the .htaccess and .htpasswd files from the administrator directory using FTP or your host\'s File Manager', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_APPLIED'] =
			__('The new wp-config.php has been written to disk', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_AUTOSAVE'] =
			__('Modify autosave interval (seconds)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_AUTOSAVE_TIP'] =
			__('When editing a post, WordPress uses Ajax to auto-save revisions to the post as you edit. You may want to increase this setting for longer delays in between auto-saves, or decrease the setting to make sure you never lose changes. The default is 60 seconds.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_CACHE'] =
			__('Enable cache', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_CACHE_NOFILE'] =
			__('You can enable this option only if the file wp-content/advanced-cache.php exists', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_CACHE_TIP'] =
			__('Enable WordPress cache', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DEBUG'] =
			__('Enable debug', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DEBUG_TIP'] =
			__('Enable WordPress debug mode. It causes very verbose information to be printed on the browser. This information may tip off hackers about how your site works. As a result it is not recommended for production sites. Only use this when you are trying to troubleshoot an error on your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DEBUG_DISPLAY'] =
			__('Display all errors in Debug mode', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DEBUG_DISPLAY_TIP'] =
			__('Display all PHP errors and warnings when WordPress Debug mode is enabled.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DEBUG_LOG'] =
			__('Enable debug log', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DEBUG_LOG_TIP'] =
			__('When enabled, WordPress will produce a log file with debug information in wp-content/debug.log. WARNING! This file can be accessed over the web by default and can be used to tip off hackers about the internal workings of your site. Only use on local development sites when you are trying to troubleshoot an error on your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DISABLE_EDIT'] =
			__('Disable file editing', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_DISABLE_EDIT_TIP'] =
			__('Disable the plugin or theme editor to prevent users from being able to edit sensitive files and potentially crash the site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_EMPTYTRASH'] =
			__('Empty trash', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_EMPTYTRASH_TIP'] =
			__('Number of days before WordPress permanently deletes posts, pages, attachments, and comments, from the trash bin. Set it to 0 to disable the trash.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_ERROR_REPORTING'] =
			__('Custom error reporting', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_ERROR_REPORTING_TIP'] =
			__('Set a custom level for PHP error reporting. See the manual for further information about the meaning for each level.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_HEADER'] =
			__('Edit WordPress Configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_IMAGEEDITS'] =
			__('Cleanup Image Edits', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_IMAGEEDITS_TIP'] =
			__('By default, WordPress creates a new set of images every time you edit an image. When you restore the original, it leaves all the edits on the server. When this option is set, only one set of image edits are ever created and when you restore the original, the edits are removed from the server.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_JSCONCAT'] =
			__('Javascript Concatenation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_JSCONCAT_TIP'] =
			__('By default, WordPress concatenates scripts in admin area. Set it to <strong>No</strong> to disable javascript concatenation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_MEMORY_LIMIT'] =
			__('Memory limit', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_MEMORY_LIMIT_TIP'] =
			__('Ask WordPress to increase current memory limit to the following value (in MegaBytes). WARNING! Values too low, e.g. below 64, may cause your site to stop loading (you will see a PHP error, 500 Internal Server error or a white page instead of your site). Values too high may be incompatible with your server. Only change this if you have a good reason to. If unsure, please ask your host about the valid range for your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_NOTAPPLIED'] =
			__('Could not write the wp-config file. Please use the Preview button to get its contents and upload it manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_POSTS'] =
			__('Post settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_POSTREVISIONS'] =
			__('Post revisions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_POSTREVISIONS_TIP'] =
			__('WordPress, by default, will save unlimited copies of each edit made to a post or page. Here you can disable this feature, set a custom limit to the revision number or revert to the default behavior.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_POSTREVISIONS_DEFAULT'] =
			__('Default', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_POSTREVISIONS_DISABLED'] =
			__('Disabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_POSTREVISIONS_CUSTOM'] =
			__('Custom', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_SAVE'] =
			__('Save without creating wp-config.php', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_SAVED'] =
			__('Changes have been successfully saved. Do not forget to apply them by creating the new wp-config.php file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_SYSTEM'] =
			__('System settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_WARNING'] =
			__('WARNING!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_WARNING_TEXT'] =
			__('By editing these fields, you\'re going to modify the wp-config.php file. Before writing a new configuration file, Admin Tools will create a backup copy of the current version with the name <strong>wp-config.admintools.php</strong>.<br/>If anything goes wrong, you can restore the previous version by simply renaming that file back to wp-config.php', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_ADVANCEDWPCONFIG_WRITE'] =
			__('Save and create wp-config.php file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_AUTOBANNEDADDRESS_IP'] =
			__('IP Address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_AUTOBANNEDADDRESS_REASON'] =
			__('Latest block reason', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_AUTOBANNEDADDRESS_UNTIL'] =
			__('Blocked until', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BADWORD_SAVED'] =
			__('Bad word saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BADWORD_WORD'] =
			__('Word', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_DELETED'] =
			__('IP ranges are now removed from the Black List', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_DESCRIPTION'] =
			__('Description', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_IP'] =
			__('IP address range', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_IP_INTRO'] =
			__('You can specify an IP or IP range in the following formats:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_IP_OPT1'] =
			__('<b>Single IP</b>, i.e. <var>192.168.1.1</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_IP_OPT2'] =
			__('<b>Simple IP Range</b>, i.e. <var>192.168.1.1-192.168.1.255</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_IP_OPT3'] =
			__('<b>Implied IP Range</b>, i.e. <var>192.168.1.</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_IP_OPT4'] =
			__('<b>CIDR Block</b>, i.e. <var>192.168.1.0/24</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_SAVED'] =
			__('Blacklisted IP saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BLACKLISTEDADDRESS_YOURIP'] =
			__('Your current IP is:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_AUTOCLOSEIN3S'] =
			__('This window will close automatically in 3 seconds.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_SELECTPUBLISHSTATE'] =
			__('Select state', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_CUSTOMSAVED'] =
			__('The custom permissions have been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_CUSTOMSAVEDAPPLIED'] =
			__('The custom permissions have been saved and applied', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_DEFAULTS'] =
			__('Default permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_DEFAULTSSAVED'] =
			__('Default permissions have been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_DEFDIRPERM'] =
			__('Directories', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_DEFFILEPERMS'] =
			__('Files', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_DONE'] =
			__('Finished fixing permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_FILE'] =
			__('File', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_FOLDER'] =
			__('Folder', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_INPROGRESS'] =
			__('Fixing permissions...', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_OWNER'] =
			__('Owner', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_PATH'] =
			__('Path', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_PERMS'] =
			__('Permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_ROOT'] =
			__('&lt; Root &gt;', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_SAVEAPPLYPERMS'] =
			__('Save and Apply custom permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_SAVEDEFAULTS'] =
			__('Save default permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_SAVEPERMS'] =
			__('Save custom permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_AWAYSCHEDULE'] =
			__('Away Schedule', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_AWAYSCHEDULE_FROM'] =
			__('from (hh:mm) ', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_AWAYSCHEDULE_TIMEZONE'] =
			__('Current server time is <strong>%s</strong>. Please double check it and change the timezone in WordPress settings if required.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_AWAYSCHEDULE_TIP'] =
			__('Disables access to your site\'s administrator area during the time period you specify here. This is useful when you are the sole administrator of the site and want to make sure that while you are asleep / away nobody can access your site\'s administrator section.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_AWAYSCHEDULE_TO'] =
			__('to (hh:mm) ', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_CONFIGSAVED'] =
			__('Web Application Firewall\'s configuration saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_CUSTOMMESSAGE_DESC'] =
			__('This message will be shown to users when their request is deemed suspicious of a security violation. Keep it short and courteous. Leave it blank to use the default message.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_CUSTOMMESSAGE_HEADER'] =
			__('Customisation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_CUSTOMMESSAGE_LABEL'] =
			__('Custom message', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_GENERATOR'] =
			__('Generator tag', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_GENERATOR_TIP'] =
			__('Enter a custom generator meta tag value, or leave blank to completely remove the tag', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_HTACCESSTIP'] =
			__('For further protection of your site, also use the .htaccess Maker feature of this plugin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_IPLOOKUPSCHEME_HTTP'] =
			__('http://', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_IPLOOKUPSCHEME_HTTPS'] =
			__('https://', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_IPLOOKUP_DESC'] =
			__('Link to an IP lookup service. {ip} will be substituted with the IP address. Default: http://ip-lookup.net/index.php?ip={ip}', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_IPLOOKUP_LABEL'] =
			__('IP Lookup Service', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_DEACTIVATENUMFREQ'] =
			__(' failed logins in ', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_EMAILAFTERIPAUTOBAN'] =
			__('Email this address after an automatic IP ban', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_EMAILAFTERIPAUTOBAN_TIP'] =
			__('Admin Tools can optionally send you an email when an IP is automatically banned, to the email address entered in this field. Leave this field empty (default) to disable this feature.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_NEVERBLOCKIPS'] =
			__('Never block these IPs', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_NEVERBLOCKIPS_TIP'] =
			__('Enter a comma-separated list of IPs which should never be automatically blocked. For example, such a list can be <em>127.0.0.1, 123.124.125.126</em> Moreover you can use IP ranges (e.g. <em>127.0.0.1-127.0.0.10</em>), implied IP range notation (<em>127.0.0.</em> for the entire 127.0.0.1 to 127.0.0.255 block) and CIDR block notation (e.g. <em>127.0.0.0/8</em>) on top of plain old IP addresses.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_PERMABAN'] =
			__('IP blacklisting of persistent offenders', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_PERMABANNUM'] =
			__('Permanently blacklist IP after', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_PERMABANNUM_2'] =
			__('automatic IP blocks', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_PERMABANNUM_TIP'] =
			__('When the previous option is enabled, after how many auto-bans an IP will be permanently banned (added to the IP blacklist).', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_PERMABAN_TIP'] =
			__('If an IP triggers this many auto-bans it will be permanently banned (added to the IP blacklist) if they are about to be auto-banned again. Make sure that you turn on the IP blacklisting by setting <em>Disallow site access to IPs in Blacklist</em> to Yes, otherwise the permanent blacklisting will have no effect.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_PROJECTHONEYPOT'] =
			__('Project Honeypot', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_SPAMMERMESSAGE'] =
			__('Show this message to blocked IPs', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_SPAMMERMESSAGE_TIP'] =
			__('Allows you to show a specific message to blocked IP addresses. You may want to explain to the user that his IP was blocked because suspicious activity was detected originating from his IP address. You can use the special text [IP] in all capital letters, without spaces between the brackets and IP, to display the user\'s IP in the message. This may be useful if someone gets accidentally blocked and asks you to help them.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSR'] =
			__('Auto-ban', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRBANNUM'] =
			__('Block for this long', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRBANNUM_TIP'] =
			__('How long the block will last. For example, setting it to 1 day will block all access from this IP address for a whole day.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRENABLE'] =
			__('IP blocking of repeat offenders', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRENABLE_TIP'] =
			__('When set to yes, the IP address of repeat offenders will be automatically banned based on the rest of the settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRNUMFREQ'] =
			__('attacks, in', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRSTRIKES'] =
			__('Block after', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_LBL_TSRSTRIKES_TIP'] =
			__('Choose how many attacks have to happen within how much time. For example, if you set it to 3 attacks in 1 hour, Admin Tools will ban an IP address from which at least 3 attacks have been blocked within the last hour.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_ACTIVEFILTERING'] =
			__('Request Filtering', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_BASIC'] =
			__('Basic Security', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_BASICSETTINGS'] =
			__('Basic features', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_EXCEPTIONS'] =
			__('Exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_FINGERPRINTING'] =
			__('Cloaking', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_WPHARDENING'] =
			__('Hardening Options', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPTGROUP_LOGGINGANDREPORTING'] =
			__('Logging & Reporting', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINFOLDER'] =
			__('Change administrator login directory to', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINFOLDER_ALERT'] =
			__('In order to use this feature you have to enable any Permalinks setting <em>except</em> Plain in the <strong>Settings, Permalinks</strong> configuration page of WordPress.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINFOLDER_TIP'] =
			__('For instance, if you enter the word <code>test</code> here you will only be able to access your site\'s administrator area with a URL similar to <code>http://www.example.com/test</code>. If you try to access it as <code>http://www.example.com/administrator</code> you will be redirected to the site\'s home page. Please note that after visiting the secret URL with your browser you will then be able to visit <code>http://www.example.com/administrator</code> without being blocked until your session expires. If you do not wish to use this feature, leave this field blank.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ALLOWSITETEMPLATE'] =
			__('Allow site templates', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ALLOWSITETEMPLATE_TIP'] =
			__('Enabling this option partially overrides the previous option (the blocking of template=foo in the URL). If the template= URL query parameter specifies the name of a template which exists in your template directory, then it will be allowed without raising a security exception. This is required only on sites which are using more than one template at the same time.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ANTISPAM'] =
			__('Anti-spam filtering based on Bad Words list', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ANTISPAM_TIP'] =
			__('When enabled, all requests containing at least one word in the <a href="%s">Bad Words</a> list will be blocked.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_BBHTTPBLKEY'] =
			__('<a href="http://www.projecthoneypot.org/httpbl_configure.php" target="_blank">Project Honeypot</a> HTTP:BL Key', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_BBHTTPBLKEY_TIP'] =
			__('Enter your HTTP:BL key. You can sign up for Project Honeypot and get your key at <a href="http://www.projecthoneypot.org/httpbl_configure.php">http://www.projecthoneypot.org/httpbl_configure.php</a>.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_BLOCKEDEMAILDOMAINS'] =
			__('Blocked email domains', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_BLOCKEDEMAILDOMAINS_TIP'] =
			__('Enter one domain for each line. Registration will be blocked if the user tries to use a domain contain in this list', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CSRFSHIELD'] =
			__('CSRF/Anti-spam form protection (CSRFShield)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CSRFSHIELD_ADVANCED'] =
			__('Advanced', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CSRFSHIELD_BASIC'] =
			__('Basic', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CSRFSHIELD_NO'] =
			__('No', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CSRFSHIELD_TIP'] =
			__('One of the major concerns regarding web forms – like login forms, contact forms, etc – is that they can be exploited by automated scripts (bots). This is usually performed to send spam messages or brute-force passwords. Admin Tools has two methods to prevent such abuse, depending on the setting of this option:<ul><li><strong>No</strong>. Turns off this feature.</li><li><strong>Basic</strong>. Performs basic referer filtering. If the browser of the visitor reports that the previous page was not one belonging to your site, Admin Tools will block processing of the form.</li><li><strong>Advanced</strong>. On top of the basic protection, Admin Tools will automatically inject a hidden field on all forms.</li></ul>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CUSTGENERATOR'] =
			__('Hide/customise generator meta tag', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CUSTGENERATOR_TIP'] =
			__('All WordPress installations set the meta generator tag, a piece of HTML in the header of all pages, to advertise the fact that your site is running on WordPress. This information is cached by search engines and is exploited by attackers to deduce that your site is running WordPress when looking for potential targets. Enabling this option allows you to set a custom value for the generator tag in the next option. Be inventive!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_DFISHIELD'] =
			__('Direct File Inclusion shield (DFIShield)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_DFISHIELD_TIP'] =
			__('When this option is enabled, Admin Tools will search the request parameters for anything which looks like a file path. If one is found, it will be scanned. If it is found to contain PHP code, the request will be rejected.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILADMINFAILEDLOGIN'] =
			__('Email this address on failed administrator login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILADMINFAILEDLOGIN_TIP'] =
			__('Enter an email address to be notified upon an unsuccessful login of anyone in your site\'s administrator backend. Leave blank to not be sent a notification. Make sure your site can send out emails first!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILADMINLOGIN'] =
			__('Email this address on successful administration login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILADMINLOGIN_TIP'] =
			__('Enter an email address to be notified upon a successful login of anyone in your site\'s administration backend. Leave blank to not be sent a notification. Make sure your site can send out emails first!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILBREACHES'] =
			__('Email this address on security exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILBREACHES_TIP'] =
			__('Enter an email address to be notified upon any security exception detected on your site. Leave blank to not be sent a notification. Make sure your site can send out emails first!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILTHROTTLE'] =
			__('Enable security exception email throttling', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_EMAILTHROTTLE_TIP'] =
			__('When enabled the frequency of emails sent by Admin Tools can be throttled down. See the Email Templates for the maximum email frequency settings.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLBLOCKSUSPICIOUS'] =
			__('Also block suspicious IPs, not just confirmed spammers', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLBLOCKSUSPICIOUS_TIP'] =
			__('Sometimes Project Honeypot is not sure if an IP belongs to a spammer or it\'s a hapless chap who clicked on the wrong link. In this case the IP is marked as "suspicious". The default behaviour is to not block these IPs. However, if you are receiving a lot of spam it\'s a good idea to enable this feature and block even "suspicious" IPs. Ultimately, some unfortunate users will be inadvertently blocked, so use this option with caution!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLENABLE'] =
			__('Enable HTTP:BL filtering', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLENABLE_TIP'] =
			__('Enables the integration with <a href="http://www.projecthoneypot.org">Project Honeypot</a>. <strong>IMPORTANT</strong>: You need to register to Project Honeypot, get a key and enter it in the next option for this feature to work.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLMAXAGE'] =
			__('Maximum age of accepted HTTP:BL results', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLMAXAGE_TIP'] =
			__('Project Honeypot reports when was the last time this IP was caught sending spam messages. The older this is (the higher the age is), the less likely is that this IP is still used by a spammer. You can chose here what will be the maximum reported age that will be blocked. The default value of 30 means that IPs which have submitted a spam message in the last 30 days will be blocked.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLTHRESHOLD'] =
			__('Minimum Threat Rating to block (0-255, default 25)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_HTTPBLTHRESHOLD_TIP'] =
			__('Project Honeypot uses a logarithmic "threat rating" to rank the possibility of a specific IP being a spammer. This options defines the minimum threat level an IP must have before it\'s blocked. A value of 25 means that this IP has submitted 100 spam messages on Project Honeypot\'s spam catching honeypots and is usually a safe indication that it belongs to a spammer. Do note that the rating is logarithmic. A value of 50 means 1,000 spam messages and a value of 75 means one million spam messages. Do not set it to values over 50, as you will most likely never block any spammer at all.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_IPBL'] =
			__('Disallow site access to IPs in Blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_IPWL'] =
			__('Allow access to Administrators that are in the WhiteList IP only', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LOGFILE'] =
			__('Keep a debug log file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LOGFILE_TIP'] =
			__('By enabling this feature, Admin Tools will write all security exceptions with extra debug information in a log file inside your Admin Tools log folder', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LOGBREACHES'] =
			__('Log security exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LOGBREACHES_TIP'] =
			__('It is suggested to keep this option enabled. When enabled, all potential security breaches —blocked by Admin Tools— will be logged in the database and made available under the Security Exceptions Log tool.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_NONEWADMINS'] =
			__('Disable editing users\' properties', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_NONEWADMINS_TIP'] =
			__('When enabled, trying to modify the settings of an existing or create a new Administrator will fail.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REASONS_NOEMAIL'] =
			__('Do not send email notifications for these reasons', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REASONS_NOEMAIL_TIP'] =
			__('Security exceptions caused by these blocking reasons will not result in an email being sent to the email address specified in <em>Email this address on security exceptions</em>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REASONS_NOLOG'] =
			__('Do not log these reasons', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REASONS_NOLOG_TIP'] =
			__('Security exceptions caused by these blocking reasons will not be logged. As a result, IPs triggering this exception repeatedly will not be automatically banned from your site. Moreover, as there is no log, it will be impossible to tell why someone is being blocked from accessing your site when they trigger one of those reasons.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_RFISHIELD'] =
			__('Remote File Inclusion block (RFIShield)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_RFISHIELD_TIP'] =
			__('Some hackers will try to force a vulnerable extension into loading PHP code directly from their server. This is done by passing an http(s):// or ftp:// URL in their request, pointing to their malicious site. When this option is enabled, Admin Tools will look for such cases, try to fetch the remote URL and scan its contents. If it is found to contain PHP code, it will block the request.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SAVEUSERSIGNUPIP'] =
			__('Save user sign-up IP in the user profile', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SAVEUSERSIGNUPIP_TIP'] =
			__('When enabled, the IP from which new users signed up will be stored as a note inside the user profile. Users created through the Users page of the administration interface will not have their IP saved as because it makes no sense to do so (it\'s an administrator registering the user account on their behalf). Third party plugins creating new user accounts may also not trigger the hook we are using to be notified of user account creation.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SHOWPWONLOGINFAILURE'] =
			__('Include password in failed login email', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SHOWPWONLOGINFAILURE_TIP'] =
			__('Should the incorrect password be included in the mail you receive when someone triggers a failed login? This only applies when <em>Treat failed logins as security exceptions</em> is enabled.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SQLISHIELD'] =
			__('SQLiShield protection against SQL injection attacks', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SQLISHIELD_TIP'] =
			__('When enabled, Admin Tools will try to detect common SQL injection attacks against your site and block them.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_TRACKFAILEDLOGINS'] =
			__('Treat failed logins as security exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_TRACKFAILEDLOGINS_TIP'] =
			__('When enabled, failed login attempts of any kind of user (even simple Subscribers users) count as security exceptions and are being logged in Admin Tools\' Security Exceptions Log. There is a very useful implication to that. Since they count as security exceptions, they count towards the exceptions limit you set up in the automatic IP blocking. Therefore, after a number of failed login attempts, the user\'s IP will be automatically blocked for the duration you have set up.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_UPLOADSHIELD'] =
			__('Uploads scanner (UploadShield)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_UPLOADSHIELD_TIP'] =
			__('When this option is enabled, Admin Tools will proactively scan all files which are uploaded. If any of these files is found to contain even a single line of PHP code, the request is blocked. Do note that not all servers support this feature. If the uploaded files directory is blocked by open_basedir restrictions, no scanning will take place.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_USE403VIEW'] =
			__('Show errors using a customisable HTML template', 'admintoolswp');
		// TODO This is wrong
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_USE403VIEW_TIP'] =
			__('By default, the Security Exceptions Message will be shown using WordPress\'s standard error message page. When this option is enabled, however, Admin Tools will use a customisable HTML template. The default HTML template file is located in the wp-admin/plugins/admintoolswp/app/view/TODO/tmpl/default.php file. DO NOT MODIFY THIS FILE DIRECTLY! Read the documentation for the proper method to create a template override.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_WHITELIST_DOMAINS'] =
			__('Whitelisted domains', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_WHITELIST_DOMAINS_TIP'] =
			__('If the IP address of the visitor who raised a security exception resolves to a domain name ending in what you enter here they will not be blocked. Effectively, these domain names have a free pass on your site. Please note that a long list will cause a big performance impact. Enter a comma separated list of the domain names you want to whitelist. The default value is .googlebot.com,.search.msn.com which whitelists the search engine indexers Google Bot (used by Google Search) and MSN Bot (used by Bing).', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_DISCLAIMER'] =
			__('DISCLAIMER', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_DISTEXT'] =
			__('Security-related plugins, like this, are not designed to offer 100% protection of your site against any attack imaginable and &ndash;even though they do increase the security of your site&ndash; in no case shall they replace a functional human brain and security fine-tuning customised for your site. At the very least, make regular backups and keep an eye for abnormal site behaviour on top of using this software.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_EMPTYROOT'] =
			__('<b>Warning</b>: PHP reports an empty path as the base directory of your site. This is caused by a bug in older versions of PHP. Please tell your host to upgrade the installed PHP version on their server. If you try using the Fix Permissions button it is very possible that you will be locked out of your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_MASTERPW'] =
			__('Password:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_MASTERPWHEAD'] =
			__('Password Protection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_MASTERPWINTRO'] =
			__('The administrator of this site has locked down some or all features of Admin Tools with a password. Please supply the password in order to be allowed access to them.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_MASTERPWSUBMIT'] =
			__('Unlock features', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_NEEDSDLID'] =
			__('You must enter your <b>Download ID</b> before you can update Admin Tools Professional. <a href="%s" target="_blank">If you don\'t know your download ID, please click here</a>.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_SECURITY'] =
			__('Security', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_TOOLS'] =
			__('Tools', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_UPDATES'] =
			__('Updates', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_DATABASETOOLS_OPTIMIZEDB'] =
			__('Repair & Optimise Tables', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_DATABASETOOLS_OPTIMIZEDB_COMPLETE'] =
			__('Optimisation is complete', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_DATABASETOOLS_OPTIMIZEDB_INPROGRESS'] =
			__('Optimisation in progress...', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_APPLIED'] =
			__('Your site is now in Emergency Off-Line mode', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_PREAPPLY'] =
			__('Clicking the button above will set your site to the Emergency Off-Line mode. In this mode nobody will be able to access your site except visitors coming from your current IP address. Should your Internet connection drop or your IP change for any reason, the only way to access your site will be removing the .htaccess file from your site\'s root using FTP. Please read this very carefully and print this page for reference.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_PREAPPLYMANUAL'] =
			__('In case this automated tools fails to create the .htaccess file on your site\'s root, please remove your current .htaccess (if any) and create a new .htaccess file with the following contents:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_PREUNAPPLY'] =
			__('Clicking the Set Offline button will re-apply Emergency Off-Line mode\'s .htaccess file on your site\'s root. Clicking the Set Online button will remove that file.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_PREUNAPPLYMANUAL'] =
			__('If setting the site back on-line fails, you can still do it using FTP. Simply remove the current .htaccess file from your site\'s root and rename the .htaccess.eom file back to .htaccess.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_SETOFFLINE'] =
			__('Set Offline', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_UNAPPLIED'] =
			__('Your site is now On-Line', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_EMERGENCYOFFLINE_UNAPPLY'] =
			__('Set Online', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_ALL'] =
			__('Select all', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_CONTINENTS'] =
			__('Continents', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_COUNTRIES'] =
			__('Countries', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_DOWNLOADGEOIPPLUGIN'] =
			__('Download the "System - Akeeba GeoIP provider plugin"', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_GEOIPPLUGINCANUPDATE'] =
			__('Admin Tools finds the country and continent of your visitors\' IP addresses using the MaxMind GeoLite2 Country database. You are advised to update it at least once per month. On most servers you can perform the update by clicking the button below. If that doesn\'t work on your server, please consult our documentation.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_GEOIPPLUGINEXISTS'] =
			__('GeoIP Database Maintenance', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_GEOIPPLUGINMISSING'] =
			__('Admin Tools\' GeoIP features require an extra plugin to be installed on your site, "System - Akeeba GeoIP provider plugin". This plugin is not distributed with Admin Tools itself, but can be downloaded from our site by clicking the button below. Once you download it, please install and enable it on your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_GEOIPPLUGINSTATUS'] =
			__('Missing GeoIP plugin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_INFO'] =
			__('This feature allows you to block access to your site for visitors coming from specific countries or continents, within a certain degree of accuracy. Please select which ones to block below.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_INFOHEAD'] =
			__('What is this?', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_MAXMIND'] =
			__('This feature includes and uses GeoLite data created by MaxMind, available from <a href="http://www.maxmind.com/">http://www.maxmind.com/</a>.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_NONE'] =
			__('Clear all', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_SAVED'] =
			__('Geographic blocking preferences have been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_UPDATEGEOIPDAT'] =
			__('Update GeoIP.dat', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_GEOGRAPHICBLOCKING_UPDATEGEOIPDATABASE'] =
			__('Update the GeoLite2 Country database', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ALLOWXMLRPC'] =
			__('Allow access to the XML-RPC server', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_APPLIED'] =
			__('The new .htaccess has been written to disk', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_APPLY'] =
			__('Save and create .htaccess', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_AUTOCOMPRESS'] =
			__('Automatically compress static resources', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_AUTOROOT'] =
			__('Redirect index.php to the site\'s root', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_AUTOROOT_ALT'] =
			__('Alternate', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_AUTOROOT_OFF'] =
			__('No', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_AUTOROOT_STD'] =
			__('Standard', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_BASICSEC'] =
			__('Basic security', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_BLOCKCOMMON'] =
			__('Block common exploits', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_CFIPFWD'] =
			__('Cloudflare IP forwarding', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_CLICKJACKING'] =
			__('Protect against clickjacking', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_CORS'] =
			__('Enable Cross-Origin Resource Sharing (CORS)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_CUSTFOOT'] =
			__('Custom .htaccess rules at the bottom of the file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_CUSTHEAD'] =
			__('Custom .htaccess rules at the top of the file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_CUSTOM'] =
			__('Custom .htaccess rules', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ENABLESEF'] =
			__('Enable SEF URLs', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ENCUTF8'] =
			__('Set the default character encoding to utf-8', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ETAGTYPE'] =
			__('Send ETag', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ETAGTYPE_DEFAULT'] =
			__('Server default', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ETAGTYPE_FULL'] =
			__('Full', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ETAGTYPE_NONE'] =
			__('None (no ETag sent)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ETAGTYPE_SIZE'] =
			__('Size only', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ETAGTYPE_SIZETIME'] =
			__('Size and Time', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_EXCEPTIONDIRS'] =
			__('Directories where all files <strong>except</strong> .php will be accessible', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_EXCEPTIONFILES'] =
			__('Files which will always be made accessible', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_EXPTIME'] =
			__('Set default expiration time to 1 hour', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_FASTCGIPASSBLOCK'] =
			__('fastcgi_pass code block setting (read the documentation)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_FILEINJ'] =
			__('Protect against common file injection attacks', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_FILEORDER'] =
			__('Force index.php parsing before index.html', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_FORCEGZIP'] =
			__('Force GZip compression for mangled Accept-Encoding headers', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_FULLACCESSDIRS'] =
			__('Directories where all files <strong>including</strong> .php will be accessible', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_HOGGERAGENTS'] =
			__('User agents to block, one per line', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_HSTSHEADER'] =
			__('HSTS Header (for HTTPS-only sites)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_HTTPHOST'] =
			__('Host name for HTTP requests (without http://)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_HTTPSHOST'] =
			__('Host name for HTTPS requests (without https://)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_HTTPSURLS'] =
			__('Force HTTPS for these URLs (do not include the domain name)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_KITCHENSINK'] =
			__('The Kitchen Sink (Expert Settings)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_LEFTOVERS'] =
			__('Block access to wp-config-sample.php and readme.html', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_MAXCLIENTBODY'] =
			__('Set maximum client body size to 1 Gb', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NGINXSECURITY'] =
			__('Tighten NginX security settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NODIRLISTS'] =
			__('Disable directory listings (recommended)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NOHOGGERS'] =
			__('Block access from specific user agents', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NOSERVERSIGNATURE'] =
			__('Remove Apache and PHP version signature', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NOTAPPLIED'] =
			__('Could not write the .htaccess file. Please use the Preview button to get its contents and upload it manually.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NOTRACETRACK'] =
			__('Disable HTTP methods TRACE and TRACK (protect against XST)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_NOTRANSFORM'] =
			__('Prevent content transformation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OLDDOMAIN'] =
			__('Redirect this (old) domain name to the new one', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OPTFHNDLCACHE'] =
			__('Optimise file handle cache', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OPTOUTBUF'] =
			__('Optimise output buffering', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OPTSOCKETS'] =
			__('Optimise socket settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OPTTCPPERF'] =
			__('Optimise TCP performance', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OPTTIMEOUT'] =
			__('Optimise timeout handling', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_OPTUTIL'] =
			__('Optimisation and utility', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_PHPEASTER'] =
			__('Disable PHP Easter Eggs', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REDUCEMIMETYPERISKS'] =
			__('Reduce MIME type security risks', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERER'] =
			__('Anti-leech protection for static resources outside images/stories', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFLECTEDXSS'] =
			__('Reflected XSS prevention', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REWRITEBASE'] =
			__('Base directory of your site (/ for domain\'s root)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SAVE'] =
			__('Save without creating .htaccess', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SAVED'] =
			__('Changes have been successfully saved. Do not forget to apply them by creating the new .htaccess file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SERVERPROT'] =
			__('Server protection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SERVERPROT_EXCEPTIONS'] =
			__('Exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SERVERPROT_FINETUNE'] =
			__('Fine-tuning', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SERVERPROT_TOGGLES'] =
			__('Protection Toggles', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SYMLINKS'] =
			__('Follow symlinks (may cause a blank page or 500 Internal Server Error)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SYMLINKS_FOLLOW'] =
			__('Yes, always', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SYMLINKS_IFOWNERMATCH'] =
			__('Only if owner matches', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SYMLINKS_OFF'] =
			__('Default', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_SYSCONF'] =
			__('System configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_TUNETEXT'] =
			__('If some of the aspects of your site suddenly stop working it\'s up to you to find the proper exceptions required for their correct operation. Instructions are given in the plugin\'s documentation.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_UTF8CHARSET'] =
			__('Set the UTF-8 character set as the default', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WARNING'] =
			__('WARNING!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WARNTEXT'] =
			__('Due to varying compatibility of the following settings among servers, applying the .htaccess file may cause inability to access your site with a white page or an Internal Server Error 500 message. In this case, remove the .htaccess and try disabling some options before reapplying.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WILLTHISWORK'] =
			__('Will the .htaccess Maker work with my server?', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WILLTHISWORK_MAYBE'] =
			__('<b>Maybe</b>. We have detected a server type which may or may not be compatible with .htaccess files. If the options below have no effect please ask your host if your server supports .htaccess files.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WILLTHISWORK_NO'] =
			__('<b>No, not at all</b>. We have detected that you are using a server type which is incompatible with .htaccess files (e.g. Microsoft IIS or NginX). Using the .htaccess Maker will have absolutely no effect on your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WILLTHISWORK_YES'] =
			__('<b>Most likely yes</b>. We have detected that your web server type is Apache which supports .htaccess files. If the options below have no effect or turning them all off still results in a 500 Internal Server Error or blank page please contact your host and ask them to enable .htaccess file support.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WWWREDIR'] =
			__('Redirect www and non-www addresses', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WWWREDIR_NO'] =
			__('Do not redirect', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WWWREDIR_NONWWW'] =
			__('Redirect www to non-www', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WWWREDIR_WWW'] =
			__('Redirect non-www to www', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY'] =
			__('Referrer Policy header', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_DISABLED'] =
			__('Do not set any policy', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_EMPTY'] =
			__('(Empty)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_NOREF'] =
			__('no-referrer', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_NOREF_DOWNGRADE'] =
			__('no-referrer-when-downgrade', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_SAMEORIGIN'] =
			__('same-origin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_ORIGIN'] =
			__('origin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_STRICTORIGIN'] =
			__('strict-origin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_ORIGINCROSS'] =
			__('origin-when-cross-origin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_STRICTORIGINGCROSS'] =
			__('strict-origin-when-cross-origin', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_REFERERPOLICY_UNSAFE'] =
			__('unsafe-url', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PARAMS_DOWNLOADID'] =
			__('Download ID', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PARAMS_SCANEMAIL_DESC'] =
			__('The scan results will be automatically sent to this email address. If you leave it blank no email will be sent.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PARAMS_SCANEMAIL_LABEL'] =
			__('Send results to this email', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PARAMS_SCAN_CONDITIONAL_EMAIL_LABEL'] =
			__('Email only on actionable items', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PARAMS_SCAN_CONDITIONAL_EMAIL_DESC'] =
			__('When enabled (default) the PHP File Change Scanner will send you an email with the scan results summary <em>only</em> when actionable items (added, modified or suspicious files) are detected.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_ALL'] =
			__('All', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_NONE'] =
			__('None', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_PASSWORD'] =
			__('Master Password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_PROTVIEWS'] =
			__('Protected Features', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_PWPROMPT'] =
			__('Password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_QUICKSELECT'] =
			__('Quick selection:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_MASTERPASSWORD_SAVED'] =
			__('Master Password and feature protection settings have been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_ALREADY_USED'] =
			__('You cannot reuse your old password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_DAYS'] =
			__('Force password expiration after this many days', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_DESCR'] =
			__('Set a password expiration for users belonging in the following roles; Admin Tools will force users to change their password in order to continue.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_LOGIN'] =
			__('Your password must be reset every %d days', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_ROLES'] =
			__('Apply this feature to the following roles', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_SAVED'] =
			__('Password expiration correctly saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PASSEXPIRATION_SET'] =
			__('Set password expiration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_DEST'] =
			__('New URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_PREFERENCE'] =
			__('Enable the URL Redirection feature?', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_PREFERENCE_SAVE'] =
			__('Save preference', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_PREFERENCE_SAVED'] =
			__('Your URL Redirection preference was saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_SAVED'] =
			__('URL Redirection saved successfully', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_SOURCE'] =
			__('Existing URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_ACKNOWLEDGED'] =
			__('Marked safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_MARKSAFE'] =
			__('Mark Safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_MARKUNSAFE'] =
			__('Unmark Safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_MD5'] =
			__('Current checksum', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_PATH'] =
			__('File path', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_STATUS'] =
			__('Status', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_STATUS_MODIFIED'] =
			__('Modified', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_STATUS_NEW'] =
			__('New', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_STATUS_SUSPICIOUS'] =
			__('Suspicious', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_THREAT_SCORE'] =
			__('Threat score', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_DIFF'] =
			__('Diff to the previous version', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_FILEINFO'] =
			__('File Information', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_SAVED'] =
			__('Scanned file status changed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_SCANDATE'] =
			__('Scan date', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_SOURCE'] =
			__('Current file source (may be different than the source scanned)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_BASICCONF'] =
			__('Basic Configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_CONFIGURATIONSAVED'] =
			__('PHP File Scanner Configuration saved successfully', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_EXCLUDEFILES'] =
			__('Excluded files not to be scanned', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_EXCLUDEFOLDERS'] =
			__('Excluded folders not to be scanned', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_FILEEXTENSIONS'] =
			__('File types to be scanned', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_MAXEXECTIME'] =
			__('Maximum execution time', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_MINEXECTIME'] =
			__('Minimum execution time', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_RUNTIMEBIAS'] =
			__('Runtime bias', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNER_TUNINGCONF'] =
			__('Fine tuning', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_ACTIONS'] =
			__('Actions &amp; Reports', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_ACTIONS_NOREPORT'] =
			__('No report generated', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_ACTIONS_VIEW'] =
			__('View Report', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_ADDED'] =
			__('Added', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_CONFIGURE'] =
			__('Configure', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_DELETED'] =
			__('Deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_MODIFIED'] =
			__('Modified', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_SAVED'] =
			__('Comment saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_START'] =
			__('Scan Date', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_SUSPICIOUS'] =
			__('Suspicious', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_THREATNONZERO'] =
			__('Possible Threats', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCAN_TOTAL'] =
			__('Total Files', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_ALTCLICRON'] =
			__('Alternative Command-Line CRON jobs', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_ALTCLICRON_INFO'] =
			__('This method is recommended only if the regular Command-Line CRON job does not complete. This method internally uses the frontend scheduling method and is a little slower than the native CLI method.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_CLICRON'] =
			__('Command-Line CRON jobs (recommended)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_CLICRON_INFO'] =
			__('This is the recommended method for all servers supporting command-line CRON jobs. This method bypasses the web interface of WordPress, achieving maximum site scan speed.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_CLIGENERICIMPROTANTINFO'] =
			__('Important', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_CLIGENERICINFO'] =
			__('Remember to substitute <em>%s</em> with the real path to your host\'s PHP <strong>CLI (Command Line Interface)</strong> executable. Do remember that you must use the PHP CLI executable; the PHP CGI (Common Gateway Interface) executable will <em>not</em> work with our CRON scripts. If unsure what this means, please consult your host. They are the only people who can provide this information.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP'] =
			__('Frontend Scheduling Feature', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_INFO'] =
			__('This method uses a public URL and a secret key to trigger a scan of your site. The scan progresses by means of HTTP redirects. Please note that most hosts\' URL-based "CRON" jobs, as well as most third-party URL-based CRON services, do not support HTTP redirects. If the examples with wget and curl below don\'t work for you, please use the frontend scheduling URL with the very cheap webcron.org third party service.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_MANYMETHODS'] =
			__('The frontend scheduling feature can be used with a great variety of methods. Click the tabs below to see all each method\'s description. Remember that all of them are explained in detail in our documentation.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_TAB_CURL'] =
			__('cURL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_TAB_SCRIPT'] =
			__('PHP Script', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_TAB_URL'] =
			__('URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_TAB_WEBCRON'] =
			__('WebCron.org', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTENDBACKUP_TAB_WGET'] =
			__('WGet', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_CURL'] =
			__('CRON scheduling using curl (SiteGround and a few other hosts):', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_CUSTOMSCRIPT'] =
			__('Custom PHP script to run the frontend scheduling:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_DISABLED'] =
			__('The frontend scheduling feature of Admin Tools is not enabled. You cannot use this scheduling method unless you enable it. Please go to Admin Tools\'s Control Panel, click on Options and enable the frontend scheduling feature. Do not forget to also specify a secret word of your liking.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_RAWURL'] =
			__('URL for use with your own scripts and third party services:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_SECRET'] =
			__('The frontend scheduling feature\'s secret key is empty. You cannot use this scheduling method unless you create a secret key. Please go to Admin Tools\'s Control Panel, click on Options and enter a secret key of your liking.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON'] =
			__('Configuration of a scan job with WebCron.org:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_ALERTS'] =
			__('Alerts', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_ALERTS_INFO'] =
			__('If you have already set up alert methods in webcron.org\'s interface, we recommend choosing an alert method here and not checking the "Only on error" so that you always get a notification when the backup CRON job runs.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_EXECUTIONTIME'] =
			__('Execution time', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_EXECUTIONTIME_INFO'] =
			__('That\'s the grid below the other options. Select when and how often you want your CRON job to run.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_INFO'] =
			__('Log in to webcron.org. In the CRON area, click on the New Cron button. Below you\'ll find what you have to enter at webcron.org\'s interface.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_LOGIN'] =
			__('Login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_LOGINPASSWORD_INFO'] =
			__('Leave this blank', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_NAME'] =
			__('Name of cronjob', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_NAME_INFO'] =
			__('Anything you like, e.g. <em>Scan of my site</em>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_PASSWORD'] =
			__('Password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_THENCLICKSUBMIT'] =
			__('Finally, click on the Submit button to finish setting up your CRON job.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_TIMEOUT'] =
			__('Timeout', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_TIMEOUT_INFO'] =
			__('180sec; if the scan doesn\'t complete, increase it. Most sites will work with a setting of 180 or 600 here. If you have a very big site which takes more than 5 minutes to scan, you might consider using the native CLI CRON job instead, as it\'s much more cost-effective.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WEBCRON_URL'] =
			__('Url you want to execute', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_WGET'] =
			__('CRON scheduling using wget (most hosts):', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_GENERICREADDOC'] =
			__('Read the documentation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_GENERICUSECLI'] =
			__('Use the following command in your host\'s CRON interface:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_HEADERINFO'] =
			__('Admin Tools offers several methods for scheduling the execution of the PHP File Change Scanner. You will find more information about each scheduling method below. Please do read the documentation of each scheduling method. It will answer a lot of your questions and will help you schedule your site scans more easily.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_RUN_FILESCANNER'] =
			__('PHP File Change Scanner Scheduling', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_BAN'] =
			__('Add to Black List', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_IP'] =
			__('IP address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_LOGDATE'] =
			__('Date', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON'] =
			__('Reason', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_ADMINDIR'] =
			__('Admin directory', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_ADMINPW'] =
			__('Admin Query String', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_ALL'] =
			__('All', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_ANTISPAM'] =
			__('Bad Words Filtering', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_AWAYSCHEDULE'] =
			__('Away Schedule', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_CSRFSHIELD'] =
			__('CSRF Shield', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_DFISHIELD'] =
			__('DFIShield', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_GEOBLOCKING'] =
			__('Geo Block', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_HTTPBL'] =
			__('Spammer (via HTTP:BL)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_IPBL'] =
			__('Site IP Blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_IPWL'] =
			__('Admin IP Whitelist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_LOGINFAILURE'] =
			__('Login failure', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_OTHER'] =
			__('Other', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_RFISHIELD'] =
			__('RFIShield', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_SELECT'] =
			__('Select a reason', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_SQLISHIELD'] =
			__('SQLi Shield', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_UPLOADSHIELD'] =
			__('UploadShield', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_WAFBLACKLIST'] =
			__('WAF Blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_NONEWADMINS'] =
			__('Edit Admin User', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_CONFIGMONITOR'] =
			__('Configuration Editing', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_UNBAN'] =
			__('Remove from Black List', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_URL'] =
			__('Target URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTTPSTOOLS_CONFIGSAVED'] =
			__('HTTPS settings have been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTTPSTOOLS_OPT_HTTPSIZER'] =
			__('Convert all links to HTTPS when site is accessed over SSL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTTPSTOOLS_OPT_HTTPSIZER_DESC'] =
			__('When enabled, all links, including the external ones, will be converted to HTTPS', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTTPSTOOLS_OPT_FORCEWPHTTPS'] =
			__('Update WordPress configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTTPSTOOLS_OPT_FORCEWPHTTPS_DESC'] =
			__('WordPress configuration will be updated in order to use HTTPS or HTTP', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEXCEPTIONS_URL'] =
			__('Excluded URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEXCEPTIONS_URL_TIP'] =
			__('While handling this URL, Admin Tools will ignore any security exceptions that could be raised. You can either set an exact URL or a regular expression', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEXCEPTIONS_DESCR'] =
			__('Description', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEXCEPTIONS_EXACT'] =
			__('Exact', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEXCEPTIONS_REGEX'] =
			__('RegEx', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEXCEPTIONS_TYPE'] =
			__('Exception type', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEMAILTEMPLATE_SAVED'] =
			__('Your email template has been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_DESCRIPTION'] =
			__('Description', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP'] =
			__('IP address range', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP_INTRO'] =
			__('You can specify an IP or IP range in the following formats:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP_OPT1'] =
			__('<b>Single IP</b>, i.e. <var>192.168.1.1</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP_OPT2'] =
			__('<b>Simple IP Range</b>, i.e. <var>192.168.1.1-192.168.1.255</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP_OPT3'] =
			__('<b>Implied IP Range</b>, i.e. <var>192.168.1.</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP_OPT4'] =
			__('<b>CIDR Block</b>, i.e. <var>192.168.1.0/24</var>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_IP_OPT5'] =
			__("<b>IPv4 lookup for a domain name</b>, i.e. <var>@example.dyndns.info</var>, useful for allowing your dynamically assigned IP.", 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_SAVED'] =
			__('Whitelisted IP saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_YOURIP'] =
			__('Your current IP is:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_COMMON_CSV'] =
			__('Export CSV', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_COMMON_NOITEMS'] =
			__('No records found', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_COMMON_PRINT'] =
			__('Print', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_APPLYDLID'] =
			__('Apply Download ID', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_FESECRETWORD_RESET'] =
			__('The Secret Word has been changed to <code>%s</code>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_MOREINFO'] =
			__('More information', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_MUSTENTERDLID'] =
			__('You need to enter your Download ID', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_PASTEDLID'] =
			__('Paste your Download ID and press the button', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_RELOADUPDATE'] =
			__('Reload update information', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_UPDATE_INFORMATION_RELOADED'] =
			__('The update information has been reloaded from the server', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_UPDATEFOUND'] =
			__('An updated version of Admin Tools (<b>%s</b>) is available for installation.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_UPDATENOW'] =
			__('Update to %s', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_GEOGRAPHICBLOCKING_DOWNLOADEDGEOIPDAT'] =
			__('GeoIP.dat was downloaded and installed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_GEOGRAPHICBLOCKING_DOWNLOADEDGEOIPDATABASE'] =
			__('The GeoLite2 Country database was downloaded and installed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_CONFIGUREHELP'] =
			__('Extra configuration parameters are also available in the Options page. See the toolbar above.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_LASTSERVERRESPONSE'] =
			__('Last server response: %s seconds ago', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_PLEASEWAIT'] =
			__('Please wait&hellip;', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_PURGE'] =
			__('Purge file cache', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_PURGE_COMPLETED'] =
			__('Scanned files cache cleared', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_PURGE_ERROR'] =
			__('An error occurred while clearing the scanned files cache', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_SCANINPROGRESS'] =
			__('Scan in progress', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_SCAN_SCANNOW'] =
			__('Scan Now', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ADMINISTRATORPASSORD_INFO'] =
			__('Whenever you visit your <code>wp-admin</code> login area you will need to enter this username and password to your browser before seeing the login form where you can enter your WordPress username and password. This will slow hackers down considerably.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ADMINLOGINEMAIL_DESC'] =
			__('Whenever an administrator login attempt is detected, successful or failed, an email will be sent to this address with information about the login username, IP address and so on.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ADMINLOGINEMAIL_LBL'] =
			__('Send an email for all administrator login attempts', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALMOSTTHERE_INTRO'] =
			__('We\'re almost there. Before proceeding you need to know what to do if things go wrong. If you are unable to log in or access your site after applying this wizard please refer to the following URLs for troubleshooting instructions:', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALMOSTTHERE_OUTRO'] =
			__('Before clicking the button below <strong>please print out this page, or take a screenshot</strong>, for your reference.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALREADYCONFIGURED_BODY'] =
			__('You have already configured Admin Tools, either manually or by running this Quick Setup Wizard in the past. We do not recommend or support running the Quick Setup Wizard again. Doing so will overwrite your Admin Tools configuration, possibly breaking your site. Are you sure you want to continue?', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALREADYCONFIGURED_BTN_NO'] =
			__('No, go back!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALREADYCONFIGURED_BTN_YES'] =
			__('Yes, run the Quick Setup Wizard', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALREADYCONFIGURED_HEAD'] =
			__('You have already configured Admin Tools.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALREADYCONFIGURED_NOSUPPORT_BODY'] =
			__('Using this wizard will overwrite all of your Admin Tools configuration settings. If you do not want to overwrite ALL of your Admin Tools settings please click the Back button now.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ALREADYCONFIGURED_NOSUPPORT_HEAD'] =
			__('You are about to overwrite all of your configuration settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_AUTOBAN_DESC'] =
			__('If an IP triggers three or more security exceptions in a minute they will blocked from accessing your site for 15 minutes.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_AUTOBAN_LBL'] =
			__('Automatically block repeat offenders', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_AUTOBLACKLIST_DESC'] =
			__('If a repeat offender\'s IP is auto-blocked three or more times their IP will be permanently blacklisted, meaning they won\'t be able to access your site any more.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_AUTOBLACKLIST_LBL'] =
			__('Blacklist incorrigible offenders', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ENABLEWAF_DESC'] =
			__('Enabling the Web Application Firewall will let Admin Tools protect you against the most common attacks against your site. You can fine tune this protection later from the Web Application Firewall, Configure WAF page of Admin Tools.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_ENABLEWAF_LBL'] =
			__('Enable Web Application Firewall', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_HEAD_ADMINSECURITY'] =
			__('Administrator security', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_HEAD_ADVANCEDSECURITY'] =
			__('Advanced security', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_HEAD_ALMOSTTHERE'] =
			__('We\'re almost there...', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_HTMAKER_DESC'] =
			__('This .htaccess file will prevent many types of attacks at the web server level.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_HTMAKER_LBL'] =
			__('Create a security tightening .htaccess', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_INTRO'] =
			__('This wizard will guide you through the basic configuration of Admin Tools. Please use it only on a new installation of Admin Tools. It will override any settings you may have already set. This wizard is not intended as a substitute for reading the <a href="%s">documentation</a> and fine tuning the protection for your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_MSG_DONE'] =
			__('Your Admin Tools setup preferences have been saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_MSG_HTMAKERNOTAPPLIED'] =
			__('Could not write the .htaccess file. Please go to the .htaccess Maker page and use the Preview button to get the new .htaccess file\'s contents. Then upload the file manually per the documentation instructions.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_MSG_IPADDEDBYWIZARD'] =
			__('Your IP as detected by the Quick Setup Wizard', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_NONEWADMINS_DESC'] =
			__('You will no longer be able to edit or create users with administrator area access, e.g. Administrators. You will also not be able to convert existing users to Administrators and so on. Trying to do that will result in a 403 Access Denied error message.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_WHITELIST_DESC'] =
			__('Access to the administrator area will only be allowed to a preset list of IP addresses. By default this only includes your current IP address, <code>%s</code>.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTIONS_FIELD_DEST_DESC'] =
			__('This is the relative URL which will trigger the redirection. It must not have the http:// or https:// protocol prefix, your domain name or a leading slash. Example: <tt>search/on/google</tt>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTIONS_FIELD_KEEPURLPARAMS'] =
			__('Keep URL Parameters', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTIONS_FIELD_KEEPURLPARAMS_DESC'] =
			__('When enabled any query string parameters in the URL will be kept in the redirection.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTIONS_FIELD_PUBLISHED_DESC'] =
			__('When set to Unpublished the redirection is disabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTIONS_FIELD_SOURCE_DESC'] =
			__('This is where the browser will be redirected to. This URL must be valid even if you turn off the redirection feature. It can be a URL to the same or another site. Example: <tt>http://www.google.com</tt>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTION_KEEPURLPARAMS_LBL_ADD'] =
			__('Add new', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTION_KEEPURLPARAMS_LBL_ALL'] =
			__('Override all', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_REDIRECTION_KEEPURLPARAMS_LBL_OFF'] =
			__('None', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANALERTS_EDIT_COMMENT'] =
			__('Edit comment', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANALERTS_SHOWCOMMENT'] =
			__('Show comment', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANALERT_SAVECOMMENT'] =
			__('Save comment', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANS_EDIT_COMMENT'] =
			__('Comment', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANS_EMAIL_HEADING'] =
			__('File Scan results', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANS_EMAIL_NOTHING_TO_REPORT'] =
			__('The PHP File Change Scanner has not detected and newly added, modified or suspicious files', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANS_EMAIL_OVERVIEW'] =
			__('Overview', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SCANS_EMAIL_SUBJECT'] =
			__('File scan results for %s', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_ACL'] =
			__('Access Control', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_ADMINPW'] =
			__('Password-protect WP Administration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_ADMINUSER'] =
			__('Administrator ID', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_ADVANCEDWPCONFIG'] =
			__('Advanced WordPress options', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_BADWORDS'] =
			__('Anti-spam Bad Words', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_BADWORDS_EDIT'] =
			__('Edit a bad word', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_DASHBOARD'] =
			__('Admin Tools', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_DASHBOARD_CORE'] =
			__('Admin Tools Core', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_DASHBOARD_PRO'] =
			__('Admin Tools Professional', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_DBPREFIX'] =
			__('Database table prefix editor', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_DBTOOLS'] =
			__('Database Tools', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_EOM'] =
			__('Emergency Off-Line', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_EXPORT_SETTINGS'] =
			__('Export Settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_FIXPERMS'] =
			__('Fix Permissions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_FIXPERMSCONFIG'] =
			__('Permissions Configuration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_GEOBLOCK'] =
			__('Geographic Blocking', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_HTMAKER'] =
			__('.htaccess Maker', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WCMAKER'] =
			__('web.config Maker', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IMPORT_SETTINGS'] =
			__('Import Settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IPAUTOBAN'] =
			__('Auto IP Blocking Administration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IPAUTOBANHISTORY'] =
			__('Auto IP Blocking History', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IPBL'] =
			__('Site IP Blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IPBL_EDIT'] =
			__('Edit IPs in Blacklist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IPWL'] =
			__('Administrator IP Whitelist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_IPWL_EDIT'] =
			__('Edit IPs in Whitelist', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_LOG'] =
			__('Security Exceptions Log', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_MASTERPW'] =
			__('Master Password', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_MALWAREDETECTION'] =
			__('Malware Detection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_NGINXMAKER'] =
			__('NginX Configuration Maker', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_PASSWORD_EXPIRATION'] =
			__('Password expiration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_QUICKSTART'] =
			__('Quick Setup Wizard', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_REDIRS'] =
			__('URL Redirection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_REDIRS_EDIT'] =
			__('Edit a URL Redirection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANALERTS'] =
			__('PHP File Change Scanner Report #%u', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANALERTS_MASTERPW'] =
			__('PHP File Change Scanner Reports', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANALERT_EDIT'] =
			__('PHP File Scanner &ndash; Report #%u &ndash; Examine file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANNER'] =
			__('Scanner Settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANS'] =
			__('PHP File Change Scanner', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANS_COMMENT'] =
			__('Edit comment', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCHEDULINGINFORMATION'] =
			__('Automatic Scanning', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_HTTPSTOOLS'] =
			__('HTTPS Tools', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_TMPLOGCHECK'] =
			__('Temp and log directory check', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAF'] =
			__('Web Application Firewall', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAFCONFIG'] =
			__('Configure WAF', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAFEXCEPTIONS'] =
			__('WAF Exceptions', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAFEXCEPTIONS_EDIT'] =
			__('Edit a WAF Exception', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAFEMAILTEMPLATE'] =
			__('Edit an email template', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAFEMAILTEMPLATES'] =
			__('Email Templates', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WAFEMAILTEMPLATES_EDIT'] =
			__('Edit an email template', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_WPTOOLS'] =
			__('WordPress Tools', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_LANGUAGE_DESC'] =
			__('Select the language of this template. This is useful for multilingual sites. Use the (All) option to create a default template.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_LANGUAGE_LBL'] =
			__('Language', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_SENDLIMIT_DESC'] =
			__('How many emails should be sent in the defined timespan. If you\'re under attack, this limit will prevent your site flooding you with email alerts.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_SENDLIMIT_LBL'] =
			__('Frequency limit', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_SUBJECT_DESC'] =
			__('The template of the email subject. You can use the same placeholders as the email body (see below).', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_SUBJECT_LBL'] =
			__('Subject', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_TEMPLATE_DESC'] =
			__('<br/><br/>The template of the email body. Please remember that you are supposed to use inline styling, not CSS classes. This is a limitation imposed by email clients and popular webmail services. You can use the following placeholders: <ul><li>[IP] Banned IP</li><li>[LOOKUP] Direct link to the IP lookup service</li><li>[REASON] Reason of the block</li><li>[DATE] Date of the block</li><li>[URL] Attacked url</li><li>[USER] Username</li><li>[COUNTRY] Country of the attack</li><li>[CONTINENT] Continent of the attack</li><li>[UA] User agent</li><li>[SITENAME] Name of your site</li></ul>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_TEMPLATE_DESC_2'] =
			__('For the <strong>User re-activate</strong> template, only the following tokens are available:<ul><li>[SITENAME] Name of your site</li><li>[DATE] Date of user de-activation</li><li>[USER] Blocked username</li><li>[IP] Registered IP</li><li>[ACTIVATE] Link to activate the user again</li></ul>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_FIELD_TEMPLATE_LBL'] =
			__('Body', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATES_NUMFREQ'] =
			__('emails, in', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATE_REASON_ADMINLOGINFAIL'] =
			__('Failed administrator login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATE_REASON_ADMINLOGINSUCCESS'] =
			__('Successful administrator login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATE_REASON_IPAUTOBAN'] =
			__('Auto-banned IP address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATE_REASON_USERREACTIVATE'] =
			__('User re-activation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WHITELISTEDADDRESSES_ERR_NOTENABLED_BODY'] =
			__('The IP addresses you enter below will <strong>not</strong> be taken into account until you enable the “Allow administrator access only to IPs in Whitelist” option in the Configure WAF page.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WHITELISTEDADDRESSES_ERR_NOTENABLED_TITLE'] =
			__('The administrator IP whitelist feature is not enabled', 'admintoolswp');
		self::$strings['COM_AKEEBA_CPANEL_ERR_FESECRETWORD_BANNED'] =
			__('The secret word is a known bad password. Please do not dictionary words, movie / series names, the names of your loved ones or pets.', 'admintoolswp');
		self::$strings['COM_AKEEBA_CPANEL_ERR_FESECRETWORD_TOOSHORT'] =
			__('The secret word is too short. Use a secret word at least 8 characters long.', 'admintoolswp');
		self::$strings['COM_AKEEBA_CPANEL_ERR_FESECRETWORD_TOOSIMPLE'] =
			__('The secret word is too simple. Try using lower and upper case letters, numbers and punctuation.', 'admintoolswp');
		self::$strings['COM_CONFIG_ADVANCED_FIELDSET_LABEL'] =
			__('Advanced Options', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WHITELISTEDADDRESS_DELETED'] =
			__('Whitelisted IP addresses deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_BADWORD_DELETED'] =
			__('Bad words deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_FROM'] =
			__('From', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_TO'] =
			__('To', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_DELETED'] =
			__('Security exceptions deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_AUTOBANNEDADDRESS_DELETED'] =
			__('Auto banned IP addresses deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_IPAUTOBANHISTORY_DELETED'] =
			__('Auto banned IP history records deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WAFEMAILTEMPLATE_DELETED'] =
			__('The email templates have been deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_REDIRECTION_DELETED'] =
			__('URL Redirection deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONTROLPANEL_SCHEDULING'] =
			__('Site maintenance scheduling (via plugin)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_FREQSECOND'] =
			__('seconds', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_FREQMINUTE'] =
			__('minutes', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_FREQHOUR'] =
			__('hours', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_FREQDAY'] =
			__('days', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_SIGNUPIP_SUBJECT'] =
			__('Sign-up IP address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_SIGNUPIP_BODY'] =
			__('<p>The user signed up to the site using IP address <strong>%s</strong></p><p>The user agent string of the user\'s browser was:<br/>%s</p><p>This information was automatically recorded in this User Note by Admin Tools Professional.</p>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREFIXPERMISSIONS_SHOW_HIDDEN'] =
			__('Apply to dot (hidden) files', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_QUICKSTART_MSG_PLEASERUNWIZARD'] =
			__('Admin Tools is not protecting your site yet. Please run the <a href="%s">Quick Setup Wizard</a> to configure Admin Tools on your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CPANEL_ERR_UPDATE_STUCK'] =
			__('We have detected that one or more tables with the <strong>%sadmintools_</strong> prefix are broken. Admin Tools will not work properly. Please ask your host to repair these tables and then <a href="%s">click here</a> to let Admin Tools update its database tables.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_BLOCKEDEMAILDOMAINS'] =
			__('The email domain %s is not allowed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_BLACKLISTEDADDRESSES_ERR_TOOMANY_TITLE'] =
			__('Too many blocked IPs may negative affect your site', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_BLACKLISTEDADDRESSES_ERR_TOOMANY_BODY'] =
			__('Too many blocked IP addresses may negatively affect your site\'s performance. Furthermore, you are most likely unwittingly blocking legitimate users. Please consult <a href="%s">our documentation</a> for more details.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CPANEL_ERR_PRIVNET_IPS'] =
			__('Admin Tools detected security exceptions from "private network" IP addresses. This usually means that there is a CDN or reverse proxy in front of your site. If this is a live site please <b>enable the IP Workarounds</b> option to fix this. If, however, you are running this site on your local computer or an Intranet you can safely ignore this message.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CPANEL_ERR_PRIVNET_ENABLE'] =
			__('Enable IP Workarounds', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CPANEL_ERR_PRIVNET_ENABLED'] =
			__('IP Workarounds correctly enabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CPANEL_ERR_PRIVNET_IGNORE'] =
			__('Ignore', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_WAFEMAILTEMPLATE_REASON_CONFIGMONITOR'] =
			__('Configuration Monitoring', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CONFIGMONITORACTION'] =
			__('Action for configuration monitoring', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CONFIGMONITORACTION_TIP'] =
			__('What do you want to do when either global or plugin configuration is enabled and a change is detected in the configuration. "Email" will simply send a warning email to the email addresses you\'ve configured to receive security exception emails and only if you have configured such email addresses. The changes in configuration will go through. "Block" will treat these changes as security exceptions. The changes in configuration will NOT go through.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CONFIGMONITORACTION_EMAIL'] =
			__('Email', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_CONFIGMONITORACTION_BLOCK'] =
			__('Block', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_PHPSHIELD'] =
			__('PHP stream wrappers block (PHPShield)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_PHPSHIELD_TIP'] =
			__('Some hackers will try to use the so-called PHP stream wrapper (they look like URLs beginning with php://, phar:// etc etc) to surreptitiously manipulate files of your site. When this option is enabled, Admin Tools will block every request which includes text matching any of the PHP stream wrappers commonly used by hackers', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SECURITYEXCEPTION_REASON_PHPSHIELD'] =
			__('PHPShield', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SELFPROTECT'] =
			__('Defend against plugin deactivation', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_CONFIGUREWAF_SELFPROTECT_TIP'] =
			__('When enabled, Admin Tools will prevent users from trying to deactivate the plugin. This means that you will also be unable to deactivate the plugin until you disable this option! Moreover please note that this has no effect against someone renaming or deleting the files of the Admin Tools plugin.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_EOF_OFFLINE_MESSAGE'] =
			__('Site temporarily offline, please come back later', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_CONTINUE'] =
			__('Continue', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ADD'] =
			__('Add new', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_SEARCH'] =
			__('Search', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_SUBMIT'] =
			__('Submit', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_SAVE'] =
			__('Save Changes', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_CANCEL'] =
			__('Cancel', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ACTION_DELETE'] =
			__('Delete', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_SAVE_OK'] =
			__('Changes successfully saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_SAVE_ERR'] =
			__('An error occurred while saving the data', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_DELETE_OK'] =
			__('Record(s) successfully deleted', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_DELETE_ERR'] =
			__('An error occurred while deleting the record(s)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_BACK_CPANEL'] =
			__('Back to Control Panel', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_PUBLISHED'] =
			__('Published', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_UNPUBLISHED'] =
			__('Unpublished', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ACTION_PUBLISH'] =
			__('Publish', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ACTION_UNPUBLISH'] =
			__('Unpublish', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ACTION_COPY'] =
			__('Copy', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ACTION_MARKSAFE'] =
			__('Mark safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ACTION_UNMARKSAFE'] =
			__('Unmark safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_ENABLE'] =
			__('Enable', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_DISABLE'] =
			__('Disable', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_COMMON_WARNING'] =
			__('Warning!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_ERR_FILESYSTEM_WRITE'] =
			__('An error occurred while trying to write the following file: %s', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_PARAMS'] =
			__('Plugin Parameters', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_PARAMS_CONFIGSAVED'] =
			__('Params saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_MARKEDSAFE'] =
			__('File(s) marked as safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_UNMARKEDSAFE'] =
			__('File(s) marked as NOT safe', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_CLICRON_INFO_WP'] =
			__('This is the recommended method for all servers supporting command-line CRON jobs. This method bypasses the web interface of WordPress, achieving maximum site scan speed.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_DISABLED_WP'] =
			__('The frontend scheduling feature of Admin Tools is not enabled. You cannot use this scheduling method unless you enable it. Please go to Admin Tools\'s Control Panel, click on Plugin Params and enable the frontend scheduling feature. Do not forget to also specify a secret word of your liking.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCHEDULINGINFORMATION_FRONTEND_SECRET_WP'] =
			__('The frontend scheduling feature\'s secret key is empty. You cannot use this scheduling method unless you create a secret key. Please go to Admin Tools\'s Control Panel, click on Plugin Params and enter a secret key of your liking.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LOGINERROR'] =
			__('Login error message', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LOGINERROR_TIP'] =
			__('WordPress leaks user information when the access credentials are wrong (ie "Wrong password for user..." or "Invalid username"). Changing the error message to something more obscure and generic will prevent attackers to gain such info.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SALTS'] =
			__('Update WP salts', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SALTS_SALTS_CHANGED'] =
			__('WordPress salts correctly changed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_FREQMONTH'] =
			__('months', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SESSIONDURATION'] =
			__('Change session duration', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SESSIONDURATION_TIP'] =
			__('By default WordPress sets session duration to 48 hours or 2 weeks if the option "Remember me" is checked. Here you can tweak those settings and customize session duration. Leave the fields empty to use the default values.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SESSIONDURATION_REGULAR'] =
			__('regular login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_SESSIONDURATION_REMEMBER'] =
			__('"Remember me" login', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SELFPROTECT_ERRMSG'] =
			__('You cannot deactivate this plugin per your settings. If you want to deactivate the plugin, go to Admin Tools, Web Application Firewall, Configure WAF and click on Defend against plugin deactivation. Then retry deactivating the plugin.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REMOVERSS'] =
			__('Remove RSS links', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REMOVERSS_TIP'] =
			__('This option will remove RSS links from your WordPress site header', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REMOVEBLOGCLIENT'] =
			__('Remove blog client links', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_REMOVEBLOGCLIENT_TIP'] =
			__('This option will remove blog client links (such as Weblog and Windows Live Writer) from your WordPress site header', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_MSG_CONTROLPANEL_CHANGELOG'] =
			__('Changelog', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_SETTINGS'] =
			__('Settings', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MAXLOGENTRIES_LBL'] =
			__('Maximum security exceptions log entries', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_PARAMS_MAXLOGENTRIES_DESC'] =
			__('Specify the maximum number of entries to keep in the security exceptions log. Excess records will be deleted. Use 0 to turn off this feature and keep all security exceptions log entries (recommended). Note: if you have thousands of old entries it will take a while for Admin Tools to remove all of the old entries. Old records are deleted in 100 record batches on each page load for performance reasons.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SIGNUPIP'] =
			__('Signup IP address', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SIGNUPUA'] =
			__('Signup User-Agent', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_FORCEHTTPS_IGNORE'] =
			__('Do not update', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_FORCEHTTPS_NO'] =
			__('Switch to HTTP', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_FORCEHTTPS_YES'] =
			__('Switch to HTTPS', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINDIR'] =
			__('Change admin URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINDIR_TIP'] =
			__('Hides the login pages (<code>wp-login.php</code>, <code>wp-admin</code>, <code>login</code>, <code>admin</code>). Please use only alphanumeric character, underscore (_) and dash (-). The following words can not be used since they have a special meaning in WordPress: <code>dashboard</code>, <code>admin</code>, <code>login</code>, <code>wp-login.php</code>.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINDIR_CUSTOMREGISTER'] =
			__('Change registration URL', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_ADMINLOGINDIR_CUSTOMREGISTER_TIP'] =
			__('Define a custom slug for user registration, for example <code>new_account</code>', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_ENABLE_PROTECTION'] =
			__('Site protection', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_EXTYPES'] =
			__('File extensions allowed', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_EXDIRS'] =
			__('Directories where <strong>only</strong> files with allowed extensions will be accessible', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_HTACCESSMAKER_WRITE'] =
			__('Save and create .htaccess file', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SALTS_DESCR_1'] =
			__('By clicking on the <strong>Update Salts</strong> button, you will change the salts used by WordPress to generate the login cookie. As a result, you (and all users) will be automatically logged off by your WordPress site, forcing to login again.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SALTS_DESCR_2'] =
			__('It\'s a best practice to update your salts from time to time and force your users to login again. This will lower the impact of any stolen cookie, since users will have to provide their password.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_SALTS_WARN'] =
			__('As soon as you click on the Update button, you will be logged out as well as all other users!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_OPTIMIZEWAF'] =
			__('Optimize WAF', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_SERVERTECH'] =
			__('Server technology', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_AUTOPREP_ENABLED'] =
			__('Auto-prepend mode enabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_AUTOPREP_DISABLED'] =
			__('Auto-prepend mode disabled', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_INVALID_ENV'] =
			__('Environment %s is not supported', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_ENABLED'] =
			__('Admin Tools is now running <em>before</em> any PHP files, granting you the maximum protection.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_NOTRUNNING'] =
			__('Admin Tools is correctly setup but the changes have not yet taken effect. If you are using LiteSpeed as your web server or CGI/FastCGI interface, please wait a couple of minutes for the changes to take effect. Please refresh this page to check if the configuration was really applied.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_ERR_UPDATE_HTACCESS'] =
			__('An error occurred while trying to update the .htaccess file. You\'ll have to manually apply the changes.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_OPTIMIZEWAF_ERR_DELETE_FILE'] =
			__('An error occurred while trying to delete the %s file. You\'ll have to manually delete it.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_SHOWCONTENT'] =
			__('Show content', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_HIDECONTENT'] =
			__('Hide content', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_SHOWDIFF'] =
			__('Show diff', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERT_HIDEDIFF'] =
			__('Hide diff', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_TITLE_SCANPARAMS'] =
			__('Scanner Preferences', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_SCANNERPARAMS_SAVED'] =
			__('Preferences saved', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_DATABASETOOLS_OPTIMIZEDB_PROGRESS'] =
			__('Progress: %s%%', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_UPDATES_ERR_DOWNLOADID'] =
			__('Please insert your Download ID inside Admin Tools for WordPress params to fetch the updates for the Pro version', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_UPDATES_ERR_PLATFORM'] =
			__('There is a new version available, but it requires a newer version of PHP or WordPress than the one you have. As a result it will not be installed.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_UPDATES_ERR_CONNECTION'] =
			__('An error occurred while trying to connect Admin Tools for WordPress update server. Please try again later.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_UPDATES_ERR_CANTUSEWPUPDATE'] =
			__('In WordPress versions previous to 4.3 you can\'t use the integrated update system. Please refer to our documentation for further info.', 'admintoolswp');
		self::$strings['NO'] =
			__('No', 'admintoolswp');
		self::$strings['YES'] =
			__('Yes', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_NOGZSUPPORT'] =
			__('Your server does not support extraction of GZip (.gz) files. The GeoLite2 Country database update cannot proceed.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_EMPTYDOWNLOAD'] =
			__('Downloading the GeoLite2 Country database failed: empty file retrieved from server. Please contact your host.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_WRITEFAILED'] =
			__('Writing the temporary file failed. Please make sure that the temporary directory defined in your site\'s Global Configuration is writeable. The GeoLite2 Country database update cannot proceed.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_CANTUNCOMPRESS'] =
			__('Cannot decompress the GeoLite2 Country database file. Probably a corrupt download? The GeoLite2 Country database update cannot proceed.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_CANTDELETEOLD'] =
			__('Cannot delete the old GeoLite2 Country database file. Please check your file ownership and permissions. The GeoLite2 Country database update cannot proceed.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_CANTWRITE'] =
			__('Cannot write the new GeoLite2 Country database file. Please check your file ownership and permissions. The GeoLite2 Country database update cannot proceed.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_MAXMINDRATELIMIT'] =
			__('MaxMind\'s servers are busy. Please retry updating the GeoLite2 Country database in 24 hours.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_MAXMIND_GENERIC'] =
			__('A connection error occurred. Please retry updating the GeoLite2 Country database in 24 hours.', 'admintoolswp');
		self::$strings['PLG_SYSTEM_AKGEOIP_ERR_INVALIDDB'] =
			__('Downloaded database seems to be invalid. Please retry updating the GeoLite2 Country database in 24 hours.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_APPLIED'] =
			__('The new web.config has been written to disk.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_APPLY'] =
			__('Save and create web.config', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_NOTAPPLIED'] =
			__('Could not write the web.config file. Please use the Preview button to get its contents and include it manually in your web.config file.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_SAVE'] =
			__('Save without creating web.config', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_SAVED'] =
			__('Changes have been successfully saved.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_TUNETEXT'] =
			__('If some of the aspects of your site suddenly stop working it\'s up to you to find the proper exceptions required for their correct operation. Instructions are given in the plugin\'s documentation.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_WARNING'] =
			__('WARNING!', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_WARNTEXT'] =
			__('Due to varying compatibility of the following settings among servers, applying the web.config file may cause inability to access your site with a white page or an Internal Server Error 500 error message. In this case, remove the web.config file and try disabling some options before reapplying.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_WILLTHISWORK'] =
			__('Will the web.config Maker work with my server?', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_WILLTHISWORK_MAYBE'] =
			__('<b>Maybe</b>. There was uncertainty in the server type detection. Simply put, we\'re not sure that you\'re running your site on Microsoft IIS, the only server type supporting web.config files. If you are told by your host that you are running on Microsoft IIS you can try using the web.config Maker.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_WILLTHISWORK_NO'] =
			__('<b>No, not at all</b>. We have detected that you are using a server type which is incompatible with web.config files (e.g. Apache or NginX). Using the web.config Maker will have absolutely no effect on your site.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_WEBCONFIGMAKER_WILLTHISWORK_YES'] =
			__('<b>Most likely yes</b>. We have detected that your web server type is IIS which supports web.config files. If the options below have no effect or turning them all off still results in a 500 Internal Server Error or blank page please contact your host and ask them to enable web.config file support.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LEAKEDPWD'] =
			__('Warn about use of well-known passwords', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LEAKEDPWD_TIP'] =
			__('When this option is enabled, Admin Tools will connect to the Have I Been Pwned database and check if the hash of the current password is known. If a match is found, the user will be blocked from using an insecure password.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LEAKEDPWD_ERR'] =
			__('Use of insecure password not allowed. Password <strong>%s</strong> is very weak since it\'s included inside attackers dictionaries.', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LEAKEDPWD_GROUPS'] =
			__('User groups to check for well-known passwords', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_LEAKEDPWD_GROUPS_TIP'] =
			__('Admin Tools will check for well-known passwords only users belonging to those groups (deafult to Super Users)', 'admintoolswp');
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_DISABLEXMLRPC'] = 'Disable XML-RPC';
		self::$strings['COM_ADMINTOOLS_LBL_CONFIGUREWAF_OPT_DISABLEXMLRPC_TIP'] = 'This will disable the XML-RPC services used by JetPack, remote blogging clients, the WordPress mobile and desktop applications, Pingback, WP-CLI and possibly other third party software or plugins. Please note that if you activate this option the <code>xmlrpc.php</code> file on your site will still be accessible. However, it will <em>always</em> report error 405 no matter what you try to do with it. This is enough to protect against security issues affecting the XML-RPC API.';
		self::$strings['COM_ADMINTOOLS_LBL_SCANALERTS_MARKALLSAFE'] = "Mark All as Safe";
	}
}